import javax.swing.event.DocumentEvent;
import javax.swing.event.DocumentListener;
import javax.swing.text.BadLocationException;
import java.awt.*;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.util.ArrayList;
import java.util.Random;
import java.io.File;  // Import the File class
import java.io.FileNotFoundException;  // Import this class to handle errors
import java.util.Scanner; // Import the Scanner class to read text files

public class Driver {
    public static void main(String[] args){
        System.out.println("Working Directory = " + System.getProperty("user.dir"));
        Random rnd = new Random();
        ViewBasicMain mainMenu = new ViewBasicMain();
        mainMenu.setupMain();
        ViewRotor rotor1Menu = new ViewRotor();
        ViewRotor rotor2Menu = new ViewRotor();
        ViewRotor rotor3Menu = new ViewRotor();
        ViewReflector reflectorMenu = new ViewReflector();
        ViewPlugboard plugboardMenu = new ViewPlugboard();
        ViewTutorial tutorialMenu = new ViewTutorial();
        rotor1Menu.setupRotorSettings();
        rotor2Menu.setupRotorSettings();
        rotor3Menu.setupRotorSettings();
        reflectorMenu.setupReflectorSettings();
        plugboardMenu.setupPlugSettings();
        tutorialMenu.setupTutorial();
        final Machine[] simulation = new Machine[2];

        mainMenu.getButtonRotorOne().addActionListener(e -> {
            mainMenu.getBasicFrame().setVisible(false);
            rotor1Menu.setLabelInputText("Rotor 1: ");
            rotor1Menu.getRotorFrame().setVisible(true);
        });
        mainMenu.getButtonRotorTwo().addActionListener(e -> {
            mainMenu.getBasicFrame().setVisible(false);
            rotor2Menu.setLabelInputText("Rotor 2: ");
            rotor2Menu.getRotorFrame().setVisible(true);
        });
        mainMenu.getButtonRotorThree().addActionListener(e -> {
            mainMenu.getBasicFrame().setVisible(false);
            rotor3Menu.setLabelInputText("Rotor 3: ");
            rotor3Menu.getRotorFrame().setVisible(true);
        });
        mainMenu.getButtonReflector().addActionListener(e -> {
            mainMenu.getBasicFrame().setVisible(false);
            reflectorMenu.getReflectorFrame().setVisible(true);
        });
        mainMenu.getButtonPlugboard().addActionListener(e -> {
            mainMenu.getBasicFrame().setVisible(false);
            plugboardMenu.getplugFrame().setVisible(true);
        });
        mainMenu.getButtonEnter().addActionListener(e -> {
            String input = mainMenu.getInputText();
            String plugboard = plugboardMenu.getTextPairsText();
            String rotor1Type = rotor1Menu.getRotorType();
            String rotor2Type = rotor2Menu.getRotorType();
            String rotor3Type = rotor3Menu.getRotorType();
            String reflectorType = reflectorMenu.getReflectorType();
            int rotor1Pos = rotor1Menu.getSliderPos();
            int rotor2Pos = rotor2Menu.getSliderPos();
            int rotor3Pos = rotor3Menu.getSliderPos();

            Rotor firstRotor = new Rotor(rotor1Type,rotor1Pos);
            Rotor secondRotor = new Rotor(rotor2Type,rotor2Pos);
            Rotor thirdRotor = new Rotor(rotor3Type,rotor3Pos);
            Reflector reflect = new Reflector(reflectorType);
            Plugboard plug = new Plugboard(plugboard);
            simulation[0] = new Machine(input,thirdRotor,secondRotor,firstRotor,reflect,plug);
            String output = simulation[0].encryptMessage();
            mainMenu.setOutputText(output);
            updateEncryptionGraphic(0, simulation, mainMenu);
            randomisePlugboard();
        });
        mainMenu.getButtonIncrease().addActionListener(e -> {
            int startingIndex = mainMenu.getGUIIndex();
            String inputText = mainMenu.getInputText().replace(" ", "");
            int textLength = inputText.length();
            if(startingIndex!=(textLength -1)){
                int newIndex = startingIndex+1;
                updateEncryptionGraphic(newIndex, simulation, mainMenu);
            }
        });
        mainMenu.getButtonDecrease().addActionListener(e -> {
            int startingIndex = mainMenu.getGUIIndex();
            if(startingIndex!=0){
                int newIndex = startingIndex -1;
                updateEncryptionGraphic(newIndex, simulation, mainMenu);
            }
        });
        mainMenu.getButtonRandom().addActionListener(e -> tutorialMenu.getTutorialFrame().setVisible(true));
        mainMenu.getButtonInfo().addActionListener(e -> {
            try {
                mainMenu.mainInfo();
            } catch (BadLocationException ex) {
                throw new RuntimeException(ex);
            }
        });
        mainMenu.getButtonInstruction().addActionListener(e -> {
            try {
                mainMenu.mainInstruct();
            } catch (BadLocationException ex) {
                throw new RuntimeException(ex);
            }
        });

        tutorialMenu.getButtonGenerate().addActionListener(e -> {
            String fRotorType = randomiseRotorType();
            String mRotorType = randomiseRotorType();
            String sRotorType = randomiseRotorType();
            int fRotorPos = (rnd.nextInt(26));
            int mRotorPos = (rnd.nextInt(26));
            int sRotorPos = (rnd.nextInt(26));
            String reflectorType = randomiseReflectorType();
            String plugboardConfig = randomisePlugboard();
            String inputPhrase = randomisePhrase();

            tutorialMenu.populateTutorial();
            tutorialMenu.setLabelFRotor(fRotorType,String.valueOf((char)(fRotorPos + 65)));
            tutorialMenu.setLabelMRotor(mRotorType,String.valueOf((char)(mRotorPos + 65)));
            tutorialMenu.setLabelSRotor(sRotorType,String.valueOf((char)(sRotorPos + 65)));
            tutorialMenu.setLabelReflect(reflectorType);
            tutorialMenu.setLabelPlugboard(plugboardConfig);
            tutorialMenu.setLabelInputText(inputPhrase);

            Rotor firstRotor = new Rotor(fRotorType,fRotorPos);
            Rotor secondRotor = new Rotor(mRotorType,mRotorPos);
            Rotor thirdRotor = new Rotor(sRotorType,sRotorPos);
            Reflector reflect = new Reflector(reflectorType);
            Plugboard plug = new Plugboard(plugboardConfig);
            simulation[1] = new Machine(inputPhrase,thirdRotor,secondRotor,firstRotor,reflect,plug);
        });
        tutorialMenu.getButtonCheck().addActionListener(e->{
            String tutorialAnswer = simulation[1].encryptMessage().toUpperCase();
            String userAnswer = tutorialMenu.getTextUserAnswer().getText().toUpperCase();
            if(userAnswer.equals(tutorialAnswer)){
                tutorialMenu.setLabelAnswer("Correct");
            }
            else{
                tutorialMenu.setLabelAnswer("Incorrect");
            }
        });
        tutorialMenu.getButtonBack().addActionListener(e -> tutorialMenu.getTutorialFrame().setVisible(false));
        rotor1Menu.getButtonBack().addActionListener(e -> {
            rotor1Menu.getRotorFrame().setVisible(false);
            mainMenu.getBasicFrame().setVisible(true);
        });
        rotor1Menu.getButtonInfo().addActionListener(e -> {
            try {
                rotor1Menu.rotorInfo();
            } catch (BadLocationException ex) {
                throw new RuntimeException(ex);
            }
        });
        rotor2Menu.getButtonBack().addActionListener(e -> {
            rotor2Menu.getRotorFrame().setVisible(false);
            mainMenu.getBasicFrame().setVisible(true);
        });
        rotor2Menu.getButtonInfo().addActionListener(e -> {
            try {
                rotor2Menu.rotorInfo();
            } catch (BadLocationException ex) {
                throw new RuntimeException(ex);
            }
        });
        rotor3Menu.getButtonBack().addActionListener(e -> {
            rotor3Menu.getRotorFrame().setVisible(false);
            mainMenu.getBasicFrame().setVisible(true);
        });
        rotor3Menu.getButtonInfo().addActionListener(e -> {
            try {
                rotor3Menu.rotorInfo();
            } catch (BadLocationException ex) {
                throw new RuntimeException(ex);
            }
        });
        reflectorMenu.getButtonBack().addActionListener(e -> {
            reflectorMenu.getReflectorFrame().setVisible(false);
            mainMenu.getBasicFrame().setVisible(true);
        });
        reflectorMenu.getButtonInstruct().addActionListener(e -> reflectorMenu.reflectorInstructions());
        reflectorMenu.getButtonInfo().addActionListener(e -> {
            try {
                reflectorMenu.reflectorInfo();
            } catch (BadLocationException ex) {
                throw new RuntimeException(ex);
            }
        });
        plugboardMenu.getButtonBack().addActionListener(e -> {
            plugboardMenu.getplugFrame().setVisible(false);
            mainMenu.getBasicFrame().setVisible(true);
        });
        rotor1Menu.getComboBoxRotorType().addActionListener(e -> {
            String rotorTurnover;
            String rotorType = rotor1Menu.getRotorType();
            switch (rotorType) {
                case "I" -> {
                    rotorTurnover = "Q";
                    rotor1Menu.setRotorIcon(1);
                } //Q E V J Z M&Z
                case "II" -> {
                    rotorTurnover = "E";
                    rotor1Menu.setRotorIcon(2);
                }
                case "III" -> {
                    rotorTurnover = "V";
                    rotor1Menu.setRotorIcon(3);
                }
                case "IV" -> {
                    rotorTurnover = "J";
                    rotor1Menu.setRotorIcon(4);
                }
                case "V" -> {
                    rotorTurnover = "Z";
                    rotor1Menu.setRotorIcon(5);
                }
                case "VI" -> {
                    rotorTurnover = "M & Z";
                    rotor1Menu.setRotorIcon(6);
                }
                case "VII" -> {
                    rotorTurnover = "M & Z";
                    rotor1Menu.setRotorIcon(7);
                }
                default -> {
                    rotorTurnover = "M & Z";
                    rotor1Menu.setRotorIcon(8);
                }
            }
            rotor1Menu.setTextTurnover(rotorTurnover);
        });
        rotor2Menu.getComboBoxRotorType().addActionListener(e -> {
            String rotorTurnover;
            String rotorType = rotor2Menu.getRotorType();
            switch (rotorType) {
                case "I" -> {
                    rotorTurnover = "Q";
                    rotor2Menu.setRotorIcon(1);
                } //Q E V J Z M&Z
                case "II" -> {
                    rotorTurnover = "E";
                    rotor2Menu.setRotorIcon(2);
                }
                case "III" -> {
                    rotorTurnover = "V";
                    rotor2Menu.setRotorIcon(3);
                }
                case "IV" -> {
                    rotorTurnover = "J";
                    rotor2Menu.setRotorIcon(4);
                }
                case "V" -> {
                    rotorTurnover = "Z";
                    rotor2Menu.setRotorIcon(5);
                }
                case "VI" -> {
                    rotorTurnover = "M & Z";
                    rotor2Menu.setRotorIcon(6);
                }
                case "VII" -> {
                    rotorTurnover = "M & Z";
                    rotor2Menu.setRotorIcon(7);
                }
                default -> {
                    rotorTurnover = "M & Z";
                    rotor2Menu.setRotorIcon(8);
                }
            }
            rotor2Menu.setTextTurnover(rotorTurnover);
        });
        rotor3Menu.getComboBoxRotorType().addActionListener(e -> {
            String rotorTurnover;
            String rotorType = rotor3Menu.getRotorType();
            switch (rotorType) {
                case "I" -> {
                    rotorTurnover = "Q";
                    rotor3Menu.setRotorIcon(1);
                } //Q E V J Z M&Z
                case "II" -> {
                    rotorTurnover = "E";
                    rotor3Menu.setRotorIcon(2);
                }
                case "III" -> {
                    rotorTurnover = "V";
                    rotor3Menu.setRotorIcon(3);
                }
                case "IV" -> {
                    rotorTurnover = "J";
                    rotor3Menu.setRotorIcon(4);
                }
                case "V" -> {
                    rotorTurnover = "Z";
                    rotor3Menu.setRotorIcon(5);
                }
                case "VI" -> {
                    rotorTurnover = "M & Z";
                    rotor3Menu.setRotorIcon(6);
                }
                case "VII" -> {
                    rotorTurnover = "M & Z";
                    rotor3Menu.setRotorIcon(7);
                }
                default -> {
                    rotorTurnover = "M & Z";
                    rotor3Menu.setRotorIcon(8);
                }
            }
            rotor3Menu.setTextTurnover(rotorTurnover);
        });
        reflectorMenu.getComboBoxReflector().addActionListener(e -> {
            int index = reflectorMenu.getComboBoxReflector().getSelectedIndex();
            reflectorMenu.setReflIcon(index);
        });
        plugboardMenu.getButtonA().addActionListener(e -> {
            String buttonText = plugboardMenu.getButtonA().getText();
            String currentPlugboard = plugboardMenu.getTextPairsText();
            plugboardMenu.setTextPairs(plugboardUpdate(buttonText,currentPlugboard));
        });
        plugboardMenu.getButtonB().addActionListener(e -> {
            String buttonText = plugboardMenu.getButtonB().getText();
            String currentPlugboard = plugboardMenu.getTextPairsText();
            plugboardMenu.setTextPairs(plugboardUpdate(buttonText,currentPlugboard));
        });
        plugboardMenu.getButtonC().addActionListener(e -> {
            String buttonText = plugboardMenu.getButtonC().getText();
            String currentPlugboard = plugboardMenu.getTextPairsText();
            plugboardMenu.setTextPairs(plugboardUpdate(buttonText,currentPlugboard));
        });
        plugboardMenu.getButtonD().addActionListener(e -> {
            String buttonText = plugboardMenu.getButtonD().getText();
            String currentPlugboard = plugboardMenu.getTextPairsText();
            plugboardMenu.setTextPairs(plugboardUpdate(buttonText,currentPlugboard));
        });
        plugboardMenu.getButtonE().addActionListener(e -> {
            String buttonText = plugboardMenu.getButtonE().getText();
            String currentPlugboard = plugboardMenu.getTextPairsText();
            plugboardMenu.setTextPairs(plugboardUpdate(buttonText,currentPlugboard));
        });
        plugboardMenu.getButtonF().addActionListener(e -> {
            String buttonText = plugboardMenu.getButtonF().getText();
            String currentPlugboard = plugboardMenu.getTextPairsText();
            plugboardMenu.setTextPairs(plugboardUpdate(buttonText,currentPlugboard));
        });
        plugboardMenu.getButtonG().addActionListener(e -> {
            String buttonText = plugboardMenu.getButtonG().getText();
            String currentPlugboard = plugboardMenu.getTextPairsText();
            plugboardMenu.setTextPairs(plugboardUpdate(buttonText,currentPlugboard));
        });
        plugboardMenu.getButtonH().addActionListener(e -> {
            String buttonText = plugboardMenu.getButtonH().getText();
            String currentPlugboard = plugboardMenu.getTextPairsText();
            plugboardMenu.setTextPairs(plugboardUpdate(buttonText,currentPlugboard));
        });
        plugboardMenu.getButtonI().addActionListener(e -> {
            String buttonText = plugboardMenu.getButtonI().getText();
            String currentPlugboard = plugboardMenu.getTextPairsText();
            plugboardMenu.setTextPairs(plugboardUpdate(buttonText,currentPlugboard));
        });
        plugboardMenu.getButtonJ().addActionListener(e -> {
            String buttonText = plugboardMenu.getButtonJ().getText();
            String currentPlugboard = plugboardMenu.getTextPairsText();
            plugboardMenu.setTextPairs(plugboardUpdate(buttonText,currentPlugboard));
        });
        plugboardMenu.getButtonK().addActionListener(e -> {
            String buttonText = plugboardMenu.getButtonK().getText();
            String currentPlugboard = plugboardMenu.getTextPairsText();
            plugboardMenu.setTextPairs(plugboardUpdate(buttonText,currentPlugboard));
        });
        plugboardMenu.getButtonL().addActionListener(e -> {
            String buttonText = plugboardMenu.getButtonL().getText();
            String currentPlugboard = plugboardMenu.getTextPairsText();
            plugboardMenu.setTextPairs(plugboardUpdate(buttonText,currentPlugboard));
        });
        plugboardMenu.getButtonM().addActionListener(e -> {
            String buttonText = plugboardMenu.getButtonM().getText();
            String currentPlugboard = plugboardMenu.getTextPairsText();
            plugboardMenu.setTextPairs(plugboardUpdate(buttonText,currentPlugboard));
        });
        plugboardMenu.getButtonN().addActionListener(e -> {
            String buttonText = plugboardMenu.getButtonN().getText();
            String currentPlugboard = plugboardMenu.getTextPairsText();
            plugboardMenu.setTextPairs(plugboardUpdate(buttonText,currentPlugboard));
        });
        plugboardMenu.getButtonO().addActionListener(e -> {
            String buttonText = plugboardMenu.getButtonO().getText();
            String currentPlugboard = plugboardMenu.getTextPairsText();
            plugboardMenu.setTextPairs(plugboardUpdate(buttonText,currentPlugboard));
        });
        plugboardMenu.getButtonP().addActionListener(e -> {
            String buttonText = plugboardMenu.getButtonP().getText();
            String currentPlugboard = plugboardMenu.getTextPairsText();
            plugboardMenu.setTextPairs(plugboardUpdate(buttonText,currentPlugboard));
        });
        plugboardMenu.getButtonQ().addActionListener(e -> {
            String buttonText = plugboardMenu.getButtonQ().getText();
            String currentPlugboard = plugboardMenu.getTextPairsText();
            plugboardMenu.setTextPairs(plugboardUpdate(buttonText,currentPlugboard));
        });
        plugboardMenu.getButtonR().addActionListener(e -> {
            String buttonText = plugboardMenu.getButtonR().getText();
            String currentPlugboard = plugboardMenu.getTextPairsText();
            plugboardMenu.setTextPairs(plugboardUpdate(buttonText,currentPlugboard));
        });
        plugboardMenu.getButtonS().addActionListener(e -> {
            String buttonText = plugboardMenu.getButtonS().getText();
            String currentPlugboard = plugboardMenu.getTextPairsText();
            plugboardMenu.setTextPairs(plugboardUpdate(buttonText,currentPlugboard));
        });
        plugboardMenu.getButtonT().addActionListener(e -> {
            String buttonText = plugboardMenu.getButtonT().getText();
            String currentPlugboard = plugboardMenu.getTextPairsText();
            plugboardMenu.setTextPairs(plugboardUpdate(buttonText,currentPlugboard));
        });
        plugboardMenu.getButtonU().addActionListener(e -> {
            String buttonText = plugboardMenu.getButtonU().getText();
            String currentPlugboard = plugboardMenu.getTextPairsText();
            plugboardMenu.setTextPairs(plugboardUpdate(buttonText,currentPlugboard));
        });
        plugboardMenu.getButtonV().addActionListener(e -> {
            String buttonText = plugboardMenu.getButtonV().getText();
            String currentPlugboard = plugboardMenu.getTextPairsText();
            plugboardMenu.setTextPairs(plugboardUpdate(buttonText,currentPlugboard));
        });
        plugboardMenu.getButtonW().addActionListener(e -> {
            String buttonText = plugboardMenu.getButtonW().getText();
            String currentPlugboard = plugboardMenu.getTextPairsText();
            plugboardMenu.setTextPairs(plugboardUpdate(buttonText,currentPlugboard));
        });
        plugboardMenu.getButtonX().addActionListener(e -> {
            String buttonText = plugboardMenu.getButtonX().getText();
            String currentPlugboard = plugboardMenu.getTextPairsText();
            plugboardMenu.setTextPairs(plugboardUpdate(buttonText,currentPlugboard));
        });
        plugboardMenu.getButtonY().addActionListener(e -> {
            String buttonText = plugboardMenu.getButtonY().getText();
            String currentPlugboard = plugboardMenu.getTextPairsText();
            plugboardMenu.setTextPairs(plugboardUpdate(buttonText,currentPlugboard));
        });
        plugboardMenu.getButtonZ().addActionListener(e -> {
            String buttonText = plugboardMenu.getButtonZ().getText();
            String currentPlugboard = plugboardMenu.getTextPairsText();
            plugboardMenu.setTextPairs(plugboardUpdate(buttonText,currentPlugboard));
        });
        plugboardMenu.getButtonInstruct().addActionListener(e -> {
            try {
                plugboardMenu.plugboardInstructions();
            } catch (BadLocationException ex) {
                throw new RuntimeException(ex);
            }
        });
        plugboardMenu.getButtonInfo().addActionListener(e -> {
            try {
                plugboardMenu.plugboardInfo();
            } catch (BadLocationException ex) {
                throw new RuntimeException(ex);
            }
        });
        plugboardMenu.getTextPairs().getDocument().addDocumentListener(new DocumentListener() {
            @Override
            public void insertUpdate(DocumentEvent e) {
                try {
                    plugboardMenu.updatePairField(plugboardMenu.getTextPairsText());
                } catch (BadLocationException ex) {
                    throw new RuntimeException(ex);
                }
                plugboardMenu.updateWarning();
            }

            @Override
            public void removeUpdate(DocumentEvent e) {
                try {
                    plugboardMenu.updatePairField(plugboardMenu.getTextPairsText());
                } catch (BadLocationException ex) {
                    throw new RuntimeException(ex);
                }
                plugboardMenu.updateWarning();
            }

            @Override
            public void changedUpdate(DocumentEvent e) {
                try {
                    plugboardMenu.updatePairField(plugboardMenu.getTextPairsText());
                } catch (BadLocationException ex) {
                    throw new RuntimeException(ex);
                }
                plugboardMenu.updateWarning();
            }
        });
    }

    private static void updateEncryptionGraphic(int newIndex, Machine[] simulation, ViewBasicMain mainMenu) {
        char[] letters =  simulation[0].getEncryptionIndex(newIndex);
        mainMenu.setTxtPlainChar(String.valueOf(letters[0]));
        mainMenu.setTxtPlugForward(String.valueOf(letters[1]));
        mainMenu.setTxtRotor1Forward(String.valueOf(letters[2]));
        mainMenu.setTxtRotor2Forward(String.valueOf(letters[3]));
        mainMenu.setTxtRotor3Forward(String.valueOf(letters[4]));
        mainMenu.setTxtRotor3Backward(String.valueOf(letters[5]));
        mainMenu.setTxtRotor2Backward(String.valueOf(letters[6]));
        mainMenu.setTxtRotor1Backward(String.valueOf(letters[7]));
        mainMenu.setTxtPlugBackward(String.valueOf(letters[8]));
        mainMenu.setTxtCypherChar(String.valueOf(letters[9]));
        mainMenu.setGUIIndex(newIndex);
    }

    public static String plugboardUpdate(String newLetter, String currentString){
        String newString;
        if(currentString.contains(newLetter)){
            int letterIndex = currentString.indexOf(newLetter);
            if(letterIndex % 3 == 1){
                letterIndex--;
            }
            String[] split = currentString.split("\\s+");
            split[(letterIndex /3)] = "";
            newString = "";
            for (int n = 0; n < split.length; n++){
                if (n != (letterIndex/3)){
                    if(split[n].length() == 1){
                        newString = newString + split[n];
                    }
                    else {
                        newString = newString + split[n] + " ";
                    }
                }
            }
        }
        else{
            int letterIndex = currentString.length();
            if(letterIndex % 3 == 1){
                newString = currentString + newLetter + " ";
            }
            else{
                newString = currentString + newLetter;
            }
        }
        return newString;
    }

    public static String randomiseRotorType(){
        Random rng = new Random();
        int randomType = rng.nextInt(8);
        System.out.println("The number type is: " + randomType);
        return switch (randomType) {
            case 0 -> "I";
            case 1 -> "II";
            case 2 -> "III";
            case 3 -> "IV";
            case 4 -> "V";
            case 5 -> "VI";
            case 6 -> "VII";
            default -> "VIII";
        };
    }
    public static String randomiseReflectorType(){
        Random rng = new Random();
        int randomType = rng.nextInt(2);
        System.out.println("Reflector type is: " + randomType);
        if(randomType == 0){
            return "UKW-B";
        }
        else {
            return "UKW-C";
        }
    }

    public static String randomisePlugboard(){
        String output = "";
        Random rng = new Random();
        int pairNum = rng.nextInt(14); //Generates 0-13, i.e. how many pairs there are going be
        ArrayList<String> remainingLetters = new ArrayList<>(); //This is how we track what letters are still valid to be used in pairs
        for(int i=0; i<26; i++){ //This for loop is how I can populate the arraylist with the alphabet
            String currLetter = String.valueOf((char) (i + 65));
            remainingLetters.add(currLetter);
        }
        System.out.println("Number of pairs: " + pairNum);
        System.out.println("Arraylist before: " + remainingLetters);
        for(int j=0; j<(pairNum*2); j++){
            int index = rng.nextInt(remainingLetters.size());
            output = output + remainingLetters.get(index);
            remainingLetters.remove(index);

            if(j % 2 == 1){
                output = output + " ";
            }
        }
        System.out.println("Arraylist after: " + remainingLetters);
        System.out.println("Plugboard config: " + output);
        return output;
    }

        public static String randomisePhrase(){
            String phrase = "###";
        try{
            File myFile = new File("C:\\Users\\serie\\eclipse-workspace\\EE475\\Enigma\\src\\Examples.txt");
            Scanner scan = new Scanner(myFile);
            Random rng = new Random();
            int lineNum = rng.nextInt(8);
            int currNum = 0;
            while(scan.hasNextLine() && currNum <= lineNum){
                phrase = scan.nextLine();
                currNum++;
            }
        } catch (FileNotFoundException e){
            System.out.println("An error occurred.");
            e.printStackTrace();
        }
        return phrase;
        }

}
